==> deltaspike-1.9.6-source-release.zip: deltaspike-1.9.6/deltaspike/modules/security/impl/src/test/java/org/apache/deltaspike/test/security/impl/authorization/securityparameterbinding/SecuredBean2.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.deltaspike.test.security.impl.authorization.securityparameterbinding;

import javax.enterprise.context.ApplicationScoped;

@ApplicationScoped
public class SecuredBean2
{
    @CustomSecurityBinding
    public boolean getBlockedResult(@MockParamBinding MockObject mockObject)
    {
        return mockObject.isValue();
    }

    public boolean getResult(MockObject mockObject)
    {
        return mockObject.isValue();
    }
    
    @CustomSecurityBinding
    public void securityCheckAfterMethodInvocation(MethodInvocationParameter parameter) {
        parameter.setMethodInvoked(true);
    }
    
    @CustomSecurityBinding
    public Void securityCheckAfterMethodInvocationWithVoidResult(MethodInvocationParameter parameter) {
        parameter.setMethodInvoked(true);
        return null;
    }
}

==> deltaspike-2.0.1-source-release.zip: deltaspike-2.0.1/deltaspike/modules/security/impl/src/test/java/org/apache/deltaspike/test/security/impl/authorization/securityparameterbinding/SecuredBean2.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.deltaspike.test.security.impl.authorization.securityparameterbinding;

import jakarta.enterprise.context.ApplicationScoped;

@ApplicationScoped
public class SecuredBean2
{
    @CustomSecurityBinding
    public boolean getBlockedResult(@MockParamBinding MockObject mockObject)
    {
        return mockObject.isValue();
    }

    public boolean getResult(MockObject mockObject)
    {
        return mockObject.isValue();
    }
    
    @CustomSecurityBinding
    public void securityCheckAfterMethodInvocation(MethodInvocationParameter parameter) {
        parameter.setMethodInvoked(true);
    }
    
    @CustomSecurityBinding
    public Void securityCheckAfterMethodInvocationWithVoidResult(MethodInvocationParameter parameter) {
        parameter.setMethodInvoked(true);
        return null;
    }
}
